#!/usr/bin/python
#
# Copyright (C) 2010, Canonical Ltd (http://www.canonical.com/)
#
# This file is part of ubuntu-server-iso-testing.
#
# ubuntu-server-iso-testing is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# ubuntu-server-iso-testing is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ubuntu-server-iso-testing.  If not, see
# <http://www.gnu.org/licenses/>.
#

"""Check disk usage matches the expected one.

Get root partition usage as stored by the late command in the preseed and
compare it against the expected value.

`df` isn't directly used in the test case to avoid getting the size of all the
packages installed because of utah, but not really present in a default
installation.

"""

import logging
import unittest
import platform


class MinimalVirtualTest(unittest.TestCase):

    def testInstallSize(self):
        logging.info('Getting root partition usage '
                     'as stored by late command...')
        with open('/var/log/utah-install') as f:
            line = f.readline()
        used = int(line.split()[-1])
        logging.info('Root partition usage: {}'.format(used))

        # 700 minimal max install size + 150 test overlay
        max_install_size = 870400

        # Add overhead for multiarch package lists on amd64
        # +32MB roughly
        if platform.machine() == "x86_64":
            max_install_size += 32256

        self.assertLess(
            used, max_install_size,
            "Usage ({}) is *not* less than the maximum expected value: {}"
            .format(used, max_install_size))

        logging.info("Usage ({}) is less than the maximum expected value: {}"
                     .format(used, max_install_size))

if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG,
                        format='%(levelname)s: %(message)s')
    unittest.main()
